react-bilde
===========
[![Latest npm version](https://img.shields.io/npm/v/react-bilde.svg)](https://www.npmjs.com/package/react-bilde) [![Build Status](https://travis-ci.org/eskilj/react-bilde.svg?branch=master)](https://travis-ci.org/eskilj/react-bilde) [![JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://standardjs.com)

[![JavaScript Style Guide](https://cdn.rawgit.com/standard/standard/master/badge.svg)](https://github.com/standard/standard)


A universal react component for displaying images. [**Updated fork of [React Universal Image](https://www.npmjs.com/package/react-universal-image), prepared for React 16.**]

## Features
* Lazy load
* Placeholder
* Progressive image loading (as on Medium.com)
* Image error fallback


## Installation
```bash
npm install react-bilde --save
```


## Usage
```jsx
import React from 'react';
import ReactDOM from 'react-dom';
import Image from 'react-bilde';

const App = () => {

    return (
        <div>
            <image
                src="img-400x200.jpg"
                srcSet="img-400x200.jpg 400w, img-800x400.jpg 800w"
                placeholder="img-20x10.jpg"
                ratio={2}
                fallback="image-not-found.jpg"
                className="post-image"
            />
        </div>
    );
};

ReactDOM.render(<App />, document.body);
```

### Props

Prop | Description | Type | Default
---- | ----------- | ---- | -------
`src` | Sets the [src](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/img#attr-src) attribute of an image (required) | string | undefined
`srcSet` | Sets the [srcset](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/img#attr-srcset) attribute of an image. | string | undefined
`placeholder` | Specify a placeholder image URL or Component for lazy loaded image. | string/node | undefined
`blur` | Specify a blur level of a placeholder image. Set `0` to disable blurring. **NOTE** Works only if placeholder was defined as image URL | number | 3
`ratio` | Image ascpect ratio. | number | undefined
`debounce` | Debounce Value. | number | 200
`animationSpeed` | Animation Speed (in ms) | number | 400
`fallback` | Fallback image src.| string | undefined
`maxWidth` | Image maximum witdth | number / string | undefined
`inline` | Image inline or not | bool | false
`id` | Image identifier | string| undefined
`className` | Image class name. | string | undefined
`alt` | Sets the alt attribute of an image and placeholder. | string | undefined
`crossOrigin` | Sets the crossorigin attribute of an image and placeholder. | string | undefined
`sizes` | Sets the sizes attribute of an image. | string | undefined


### Contributing

See the [contribution guidelines](https://github.com/eskilj/react-bilde/blob/master/CONTRIBUTING.md) before creating a pull request.

<!--### Thanks-->
<!--Huge thanks to anyone who has [contributed](https://github.com/eskilj/react-bilde/graphs/contributors)-->

### Polyfills
* If you are using `npm` and need to support [browsers without `Promise`](http://caniuse.com/#feat=promises) you will need a [`Promise` polyfill](https://github.com/stefanpenner/es6-promise).
* To support IE11 you will need to use [`babel-polyfill`](https://babeljs.io/docs/usage/polyfill) or a similar ES2015+ polyfill.